@@ -1,9 +1,6 @@
 # for reproducibility
 set.seed(123)
 
-# for pretty-printing tibble
-options(tibble.width = Inf, pillar.bold = TRUE, pillar.neg = TRUE)
-
 # ----------------------- parametric -----------------------
 
 centrality_description(iris, Species, Sepal.Length)
